@@ -1,6 +1,6 @@
 package List::Objects::WithUtils;
 {
-  $List::Objects::WithUtils::VERSION = '1.003001';
+  $List::Objects::WithUtils::VERSION = '1.004000';
 }
 use Carp;
 use strictures 1;
@@ -171,6 +171,9 @@ List::Objects::WithUtils - Object interfaces to lists with useful methods
   if ( $hash->keys->any_items eq 'snacks' ) {
     ...    
   }
+  if ( $hash->values->all_items > 10 ) {
+    ...
+  }
 
   # Autoboxed native data types:
   use List::Objects::WithUtils 'autobox';
@@ -186,11 +189,10 @@ List::Objects::WithUtils - Object interfaces to lists with useful methods
 =head1 DESCRIPTION
 
 A set of roles and classes defining an object-oriented interface to Perl
-hashes and arrays. Originally derived from L<Data::Perl>.
+hashes and arrays with useful utility methods, junctions, and optional
+autoboxing.
 
-Some commonly used functions from L<List::Util>, L<List::MoreUtils>, and
-L<List::UtilsBy> are conveniently provided as methods. Junctions, 
-as provided by L<Syntax::Keyword::Junction>, are also available.
+Originally derived from L<Data::Perl>.
 
 B<array> is imported from L<List::Objects::WithUtils::Array> and creates a new
 ARRAY-type object. 
@@ -301,7 +303,9 @@ Phillips (CPAN: MATTP), haarg, and others.
 
 Immutable array objects were inspired by L<Const::Fast>.
 
-Most of this code relies entirely on other widely-used modules, including:
+Junctions are adapted from L<Perl6::Junction> by Carl Franks.
+
+Much of this code simply wraps other widely-used modules, including:
 
 L<List::Util>
 
@@ -309,6 +313,4 @@ L<List::MoreUtils>
 
 L<List::UtilsBy>
 
-L<Syntax::Keyword::Junction>
-
 =cut
